Mustache templating system Bindings for Pyramid
===============================================

Bindings for the `Mustache templating system
<http://mustache.github.io/>`_ for the Pyramid_ web framework

Heavily based on the pyramid_chameleon_ package

.. _Pyramid: http://pylonsproject.org/
.. _pyramid_chameleon: https://github.com/Pylons/pyramid_chameleon

